[Bf-blender-cvs] [b46aad19c05] master: Libmv: Make ERROR a default printing severity

Sergey Sharybin noreply at git.blender.org
Fri Apr 28 16:47:51 CEST 2017


Commit: b46aad19c05c3a0f713b4ad9e3b4c771119df0d1
Author: Sergey Sharybin
Date:   Fri Apr 28 16:47:35 2017 +0200
Branches: master
https://developer.blender.org/rBb46aad19c05c3a0f713b4ad9e3b4c771119df0d1

Libmv: Make ERROR a default printing severity

===================================================================

M	intern/libmv/intern/logging.cc

===================================================================

diff --git a/intern/libmv/intern/logging.cc b/intern/libmv/intern/logging.cc
index 9b8adf09a97..863832cb72b 100644
--- a/intern/libmv/intern/logging.cc
+++ b/intern/libmv/intern/logging.cc
@@ -30,10 +30,10 @@
 
 void libmv_initLogging(const char* argv0) {
   using LIBMV_GFLAGS_NAMESPACE::SetCommandLineOption;
   // Make it so FATAL messages are always print into console.
   char severity_fatal[32];
   snprintf(severity_fatal, sizeof(severity_fatal), "%d",
-           google::GLOG_FATAL);
+           google::GLOG_ERROR);
   google::InitGoogleLogging(argv0);
   SetCommandLineOption("logtostderr", "1");
   SetCommandLineOption("v", "0");
@@ -30,10 +30,10 @@
 void libmv_initLogging(const char* argv0) {
   using LIBMV_GFLAGS_NAMESPACE::SetCommandLineOption;
-  // Make it so FATAL messages are always print into console.
+  // Make it so ERROR messages are always print into console.
   char severity_fatal[32];
   snprintf(severity_fatal, sizeof(severity_fatal), "%d",




More information about the Bf-blender-cvs mailing list